@@ -31,6 +31,7 @@ import qualified Data.Set as Set
 import Data.List (intercalate)
 import Data.Time
 import Data.Monoid (mempty)
+import Text.Printf
 
 import Paths_bustle
 import Bustle.Application.Monad
@@ -46,6 +47,7 @@ import Bustle.UI.OpenTwoDialog (setupOpenTwoDialog)
 import Bustle.UI.Recorder
 import Bustle.UI.Util (displayError)
 import Bustle.StatisticsPane
+import Bustle.Translation (__)
 import Bustle.Loader
 
 import qualified Control.Exception as C
@@ -93,7 +95,6 @@ data WindowInfo =
 
 data BConfig =
     BConfig { debugEnabled :: Bool
-            , bustleIcon :: Maybe Pixbuf
             , methodIcon :: Maybe Pixbuf
             , signalIcon :: Maybe Pixbuf
             }
@@ -118,11 +119,10 @@ uiMain = failOnGError $ do
     -- FIXME: get a real option parser
     let debug = any isDebug args
 
-    [bustle, method, signal] <- mapM loadPixbuf
-        ["bustle.png", "dfeet-method.png", "dfeet-signal.png"]
+    [method, signal] <- mapM loadPixbuf
+        ["dfeet-method.png", "dfeet-signal.png"]
 
     let config = BConfig { debugEnabled = debug
-                         , bustleIcon = bustle
                          , methodIcon = method
                          , signalIcon = signal
                          }
@@ -205,7 +205,7 @@ loadLogWith getWindow logDetails = do
 
     case ret of
       Left (LoadError f e) -> io $
-          displayError Nothing ("Could not read '" ++ f ++ "'") (Just e)
+          displayError Nothing (printf (__ "Could not read '%s'") f) (Just e)
       Right () -> return ()
 
 startRecording :: B ()
@@ -281,15 +281,15 @@ promptToSave wi = io $ do
     case mdetails of
         Just (RecordedLog tempFilePath) -> do
             let tempFileName = takeFileName tempFilePath
-                title = "Save log “" ++ tempFileName ++ "” before closing?"
+                title = printf (__ "Save log '%s' before closing?") tempFileName
             prompt <- messageDialogNew (Just (wiWindow wi))
                                        [DialogModal]
                                        MessageWarning
                                        ButtonsNone
                                        title
             messageDialogSetSecondaryText prompt
-                "If you don’t save, this log will be lost forever."
-            dialogAddButton prompt "Close _without saving" ResponseClose
+                (__ "If you don't save, this log will be lost forever.")
+            dialogAddButton prompt (__ "Close _Without Saving") ResponseClose
             dialogAddButton prompt stockCancel ResponseCancel
             dialogAddButton prompt stockSave ResponseYes
 
@@ -337,10 +337,8 @@ emptyWindow = do
   openTwoDialog <- embedIO $ \r ->
       setupOpenTwoDialog builder window $ \f1 f2 ->
           makeCallback (loadInInitialWindow (TwoLogs f1 f2)) r
-  withProgramIcon (windowSetIcon openTwoDialog)
 
   -- Set up the window itself
-  withProgramIcon (windowSetIcon window)
   embedIO $ onDestroy window . makeCallback maybeQuit
 
   -- File menu and related buttons
@@ -356,8 +354,7 @@ emptyWindow = do
       onActivateLeaf openTwoItem $ widgetShowAll openTwoDialog
 
   -- Help menu
-  withProgramIcon $ \icon -> io $
-      onActivateLeaf aboutItem $ showAboutDialog window icon
+  io $ onActivateLeaf aboutItem $ showAboutDialog window
 
   m <- asks methodIcon
   s <- asks signalIcon
@@ -462,7 +459,7 @@ wiSetLogDetails :: WindowInfo
                 -> IO ()
 wiSetLogDetails wi logDetails = do
     writeIORef (wiLogDetails wi) (Just logDetails)
-    windowSetTitle (wiWindow wi) (logWindowTitle logDetails ++ " — Bustle")
+    windowSetTitle (wiWindow wi) (printf (__ "%s - Bustle") (logWindowTitle logDetails))
 
 setPage :: MonadIO io
         => WindowInfo
@@ -507,9 +504,7 @@ displayLog wi@(WindowInfo { wiWindow = window
     statsPaneSetMessages statsPane sessionMessages systemMessages
 
     widgetSetSensitivity viewStatistics True
-    -- the version of gtk2hs I'm using has a checkMenuItemToggled which is a
-    -- method not a signal.
-    connectGeneric "toggled" False viewStatistics $ do
+    viewStatistics `on` checkMenuItemToggled $ do
         active <- checkMenuItemGetActive viewStatistics
         if active
             then widgetShow statsBook
@@ -526,9 +521,6 @@ displayLog wi@(WindowInfo { wiWindow = window
 
   return ()
 
-withProgramIcon :: (Maybe Pixbuf -> IO a) -> B a
-withProgramIcon f = asks bustleIcon >>= io . f
-
 loadPixbuf :: FilePath -> IO (Maybe Pixbuf)
 loadPixbuf filename = do
   iconName <- getDataFileName $ "data/" ++ filename
